@@ -1,20 +1,19 @@
 #![allow(unused_variables)]
 #![allow(clippy::many_single_char_names)]
 
+use crate::activated_color;
 use fltk::{
     app,
     draw::*,
     enums::{Color, FrameType},
     misc::Tooltip,
 };
-use crate::activated_color;
 
 pub(crate) mod aero;
-pub(crate) mod aqua;
+pub(crate) mod aqua_classic;
 pub(crate) mod blue;
 pub(crate) mod classic;
 pub(crate) mod dark;
-pub(crate) mod fluent;
 pub(crate) mod greybird;
 pub(crate) mod high_contrast;
 pub(crate) mod metro;
